@@ -1,6 +1,8 @@
 parseName <- function(x, surnameFirst=(median(regexpr(',', x))>0),
-          suffix=c('Jr.', 'I', 'II', 'III', 'IV', 'Sr.'),
-          fixNonStandard=subNonStandardNames, ...){
+          suffix=c('Jr.', 'I', 'II', 'III', 'IV', 'Sr.', 'Dr.', 
+                   'Jr', 'Sr'),
+          fixNonStandard=subNonStandardNames, 
+          removeSecondLine=TRUE, ...){
 ##
 ## 1.  length(x)<1?
 ##
@@ -11,8 +13,30 @@ parseName <- function(x, surnameFirst=(median(regexpr(',', x))>0),
          dimnames=list(NULL, c("surname", "givenName")))
       return(mat0)
   }
+  x00 <- x
+# Force eval of default if(missing(surnameFirst))
+# else x changes and surnameFirst may change 
+  miSNF <- missing(surnameFirst)
+  surnameFirst <- surnameFirst
+  x <- x01 <- stripBlanks(x00)
 ##
-## 2.  Drop "(AL)", etc.
+## 2.  secondLine?
+##
+  if(removeSecondLine){
+    X2. <- strsplit(x01, '\n')
+    x2 <- sapply(X2., function(xx){
+      xx2 <- xx[-1]
+      paste(xx2, collapse='\n')
+    } ) 
+    no2 <- sapply(X2., length)
+    x2[no2<2] <- NA
+    x <- sapply(X2., '[', 1)
+    nch0 <- (nchar(x01)<1)
+    x[nch0] <- x01[nch0] 
+    x <- stripBlanks(x)
+  } else x2 <- NULL
+##
+## 3.  Drop "(AL)", etc.
 ##
   dropEndParen <- function(x){
       endParen <- grep(')$', x)
@@ -26,7 +50,7 @@ parseName <- function(x, surnameFirst=(median(regexpr(',', x))>0),
           x[endParen] <- x.woP
       }
 #      if(require(tis)){
-          x <- stripBlanks(x)
+#          x <- stripBlanks(x)
 #      } else {
 #          warning('need stripBlanks{tis} to delete leading and trailing',
 #                  ' blanks;  not available')
@@ -36,23 +60,20 @@ parseName <- function(x, surnameFirst=(median(regexpr(',', x))>0),
   x0 <- x
   x <- dropEndParen(x)
 ##
-## 3.  surnameFirst
+## 4.  surnameFirst
 ##
-  if(missing(surnameFirst))
-      surnameFirst <- surnameFirst
-#
   if(surnameFirst){
       Sep <- regexpr(',', x)
       oops <- which(Sep<0)
-      if((no <- length(oops))>0){
+      if(miSNF & (no <- length(oops))>0){
           err <- paste(no, ' of ', length(x), ' elements of x ',
                        'are NOT in surnameFirst format.  ',
                        'The first is ', x[oops[1]],
                '.  Assume they are in (givenName surname) format.')
           warning(err)
-          fix0 <- parseName(x[oops])
-          fix1 <- paste(fix0[, 2], fix0[, 1], sep=', ')
-          x[oops] <- fix1
+#          fix0 <- parseName(x[oops])
+#          fix1 <- paste(fix0[, 2], fix0[, 1], sep=', ')
+#          x[oops] <- fix1
       }
       sur. <- substring(x, 1, Sep-1)
 #     drop (AL), etc.
@@ -60,7 +81,7 @@ parseName <- function(x, surnameFirst=(median(regexpr(',', x))>0),
 #
       giv <- substring(x, Sep+1)
 #      if(require(tis)){
-          giv <- stripBlanks(giv)
+#          giv <- stripBlanks(giv)
 #      } else {
 #          warning('need stripBlanks{tis} to delete leading and trailing',
 #                  ' blanks;  not available')
@@ -69,10 +90,10 @@ parseName <- function(x, surnameFirst=(median(regexpr(',', x))>0),
       Sur. <- strsplit(Sur, ' ')
       look4suf <- sapply(Sur., tail, n=1)
       suf <- (look4suf %in% suffix)
-      surname <- rep(NA, nx)
+      surname <- rep('', nx)
       lx <- sapply(Sur., length)-suf
       for(ix in 1:nx){
-          xi <- Sur.[[ix]][1:lx[ix]]
+          xi <- Sur.[[ix]][seq(length=lx[ix])]
           surname[ix] <- paste(xi, collapse=' ')
       }
 #
@@ -83,20 +104,31 @@ parseName <- function(x, surnameFirst=(median(regexpr(',', x))>0),
       return(out)
   }
 ##
-## 4.  strsplit on either blank or comma
+## 5.  strsplit on either blank or comma
 ##
   x. <- strsplit(x, ' |,')
 ##
-## 5.  Suffix?
+## 6.  Suffix?
 ##
   look4suf <- sapply(x., tail, n=1)
   suf <- (look4suf %in% suffix)
 ##
-## 6.  parse
+## 7.  parse
 ##
-  givenName <- surname <- rep(NA, nx)
+  givenName <- surname <- rep('', nx)
   lx <- sapply(x., length)-suf
+# Check for ending comma 
+  endComma <- regexpr(',$', x)
   for(ix in 1:nx){
+    if(lx[ix]<1) next
+    if(lx[ix]<2) {
+#   only one name 
+      if(endComma[ix]>0){
+        surname[[ix]] <- x.[[ix]]
+      } else {
+        givenName[[ix]] <- x.[[ix]]
+      }
+    } else {
       xi <- x.[[ix]][1:lx[ix]]
 #      ni <- length(xi)
       ni0 <- nchar(xi)
@@ -107,16 +139,20 @@ parseName <- function(x, surnameFirst=(median(regexpr(',', x))>0),
       if(suf[ix])
           givenName[ix] <- paste(givenName[ix], look4suf[ix],
                                  sep=', ')
+    }
   }
 ##
-## 7.  fixNonStandard
+## 8.  fixNonStandard
 ##
   Sur <- fixNonStandard(surname, ...)
   Giv <- fixNonStandard(givenName, ...)
 ##
-## 8.  Done
+## 9.  Done
 ##
   out <- cbind(surname=Sur, givenName=Giv)
+  nchx2 <- nchar(x2)
+  nchx2[is.na(x2)] <- 0 
+  if(any(nchx2>0))attr(out, 'secondLine') <- x2
   out
 }
 
