@@ -30,12 +30,14 @@ subNonStandardCharacters <- function(x,
   for(ix in seq(length=nx)){
       gi <- which(!(x.[[ix]] %in% standardCharacters))
       if(length(gi)>0){
+        if(!is.na(xo[ix])){
           gi. <- range(gi)
           ni <- length(x.[[ix]])
           xi1 <- paste(x.[[ix]][seq(length=gi.[1]-1)], collapse='')
           xie <- paste(x.[[ix]][seq(from=gi.[2]+1, length=ni-gi.[2])],
                        collapse='')
           xo[ix] <- paste(xi1, replacement, xie, sep="")
+        }
       }
   }
 ##
